nengo\_spa\.vector_generation
=============================

.. automodule:: nengo_spa.vector_generation
   :show-inheritance:

   .. rubric:: Classes

   .. autosummary::

      AxisAlignedVectors
      UnitLengthVectors
      UnitaryVectors
      OrthonormalVectors
      ExpectedUnitLengthVectors
